@@ -25,9 +25,12 @@
 #include <KStandardAction>
 #endif
 
+#if KFDBusAddons_FOUND
+#include <KDBusService>
+#endif
+
 #if defined KFXmlGui_FOUND
 #include <KActionCollection>
-#include <KAboutApplicationDialog>
 #include <KHelpMenu>
 #include <KBugReport>
 #include <KShortcutsDialog>
@@ -57,7 +60,6 @@
 #include <QMimeDatabase>
 #include <QMimeType>
 
-
 class ElisaApplicationPrivate
 {
 public:
@@ -95,6 +97,26 @@ public:
     KColorSchemeManager *mSchemes = nullptr;
 };
 
+ElisaApplication *ElisaApplication::create(QQmlEngine *engine, QJSEngine *scriptEngine)
+{
+    Q_UNUSED(scriptEngine)
+    auto newApplication = std::make_unique<ElisaApplication>();
+
+#if KFDBusAddons_FOUND
+    auto *elisaService = new KDBusService(KDBusService::Unique, newApplication.get());
+#endif
+
+#if KFDBusAddons_FOUND
+    QObject::connect(elisaService, &KDBusService::activateActionRequested, newApplication.get(), &ElisaApplication::activateActionRequested);
+    QObject::connect(elisaService, &KDBusService::activateRequested, newApplication.get(), &ElisaApplication::activateRequested);
+    QObject::connect(elisaService, &KDBusService::openRequested, newApplication.get(), &ElisaApplication::openRequested);
+#endif
+
+    newApplication->setQmlEngine(engine);
+
+    return newApplication.release();
+}
+
 ElisaApplication::ElisaApplication(QObject *parent) : QObject(parent), d(std::make_unique<ElisaApplicationPrivate>(this))
 {
     auto configurationFileName = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation);
@@ -154,10 +176,15 @@ void ElisaApplication::setupActions(const QString &actionName)
     }
 
     if (actionName == QLatin1String("help_about_app") && KAuthorized::authorizeAction(actionName)) {
-        auto aboutAppAction = KStandardAction::aboutApp(this, &ElisaApplication::aboutApplication, this);
+        auto aboutAppAction = KStandardAction::aboutApp(this, &ElisaApplication::openAboutAppPage, this);
         d->mCollection.addAction(aboutAppAction->objectName(), aboutAppAction);
     }
 
+    if (actionName == QLatin1String("help_about_kde") && KAuthorized::authorizeAction(actionName)) {
+        auto aboutKDEAction = KStandardAction::aboutKDE(this, &ElisaApplication::openAboutKDEPage, this);
+        d->mCollection.addAction(aboutKDEAction->objectName(), aboutKDEAction);
+    }
+
     if (actionName == QLatin1String("options_configure") && KAuthorized::authorizeAction(actionName)) {
         auto preferencesAction = KStandardAction::preferences(this, &ElisaApplication::configureElisa, this);
         d->mCollection.addAction(preferencesAction->objectName(), preferencesAction);
@@ -222,6 +249,8 @@ void ElisaApplication::setupActions(const QString &actionName)
     }
 
     d->mCollection.readSettings();
+#else
+    Q_UNUSED(actionName)
 #endif
 }
 
@@ -284,18 +313,6 @@ void ElisaApplication::appHelpActivated()
     QDesktopServices::openUrl(QUrl(QStringLiteral("help:/")));
 }
 
-void ElisaApplication::aboutApplication()
-{
-#if KFXmlGui_FOUND
-    static QPointer<QDialog> dialog;
-    if (!dialog) {
-        dialog = new KAboutApplicationDialog(KAboutData::applicationData(), nullptr);
-        dialog->setAttribute(Qt::WA_DeleteOnClose);
-    }
-    dialog->show();
-#endif
-}
-
 void ElisaApplication::reportBug()
 {
 #if KFXmlGui_FOUND
@@ -318,19 +335,6 @@ void ElisaApplication::configureShortcuts()
 #endif
 }
 
-void ElisaApplication::configureElisa()
-{
-    if (!d->mEngine)
-    {
-        return;
-    }
-
-    QQmlComponent configurationDialogComponent(d->mEngine,
-                                               QUrl(QStringLiteral("qrc:/qml/ElisaConfigurationDialog.qml")));
-
-    configurationDialogComponent.create();
-}
-
 void ElisaApplication::goBack() {}
 
 void ElisaApplication::find() {}
@@ -373,7 +377,7 @@ DataTypes::EntryDataList ElisaApplication::checkFileListAndMakeAbsolute(const Da
     auto filesToOpen = DataTypes::EntryDataList{};
 
     for (const auto &oneFile : filesList) {
-        auto trackUrl = std::get<0>(oneFile)[DataTypes::ResourceRole].toUrl();
+        auto trackUrl = oneFile.musicData[DataTypes::ResourceRole].toUrl();
         if (trackUrl.scheme().isEmpty() || trackUrl.isLocalFile()) {
             auto newFile = QFileInfo(trackUrl.toLocalFile());
             if (trackUrl.scheme().isEmpty()) {
@@ -389,9 +393,9 @@ DataTypes::EntryDataList ElisaApplication::checkFileListAndMakeAbsolute(const Da
             }
 
             if (newFile.exists()) {
-                auto trackData = std::get<0>(oneFile);
+                auto trackData = oneFile.musicData;
                 trackData[DataTypes::ResourceRole] = QUrl::fromLocalFile(newFile.canonicalFilePath());
-                filesToOpen.push_back({trackData, std::get<1>(oneFile), {}});
+                filesToOpen.push_back({trackData, oneFile.title, {}});
             }
         } else {
             filesToOpen.push_back(oneFile);
@@ -406,12 +410,6 @@ void ElisaApplication::initialize()
     initializeModels();
     initializePlayer();
 
-#if defined Q_OS_ANDROID
-    QIcon::setThemeName(QStringLiteral("Breeze"));
-    QIcon::setFallbackSearchPaths({QIcon::themeSearchPaths().first() + QStringLiteral("/icons")});
-    QIcon::setThemeSearchPaths({QIcon::themeSearchPaths().first()});
-#endif
-
     Q_EMIT initializationDone();
 }
 
