@@ -7,11 +7,16 @@
 #include "config-upnp-qt.h"
 #include "elisa-version.h"
 
+#include "colorschemepreviewimageprovider.h"
 #include "elisaapplication.h"
 #include "elisa_settings.h"
 
 #include "localFileConfiguration/elisaconfigurationdialog.h"
 
+#if KFFileMetaData_FOUND
+#include "embeddedcoverageimageprovider.h"
+#endif
+
 //#define QT_QML_DEBUG
 
 #include <KLocalizedString>
@@ -37,18 +42,17 @@
 #include <QQmlFileSelector>
 #include <QQuickStyle>
 
-#if QtAndroidExtras_FOUND
-#include <QAndroidService>
-#endif
-
 #include <memory>
 
-#if QtAndroidExtras_FOUND
-#include <QAndroidJniObject>
-#include <QtAndroid>
+#ifdef Q_OS_ANDROID
+#include "android/androidcoverimageprovider.h"
+
+#include <QCoreApplication>
+#include <QJniObject>
+#include <QtCore/private/qandroidextras_p.h>
 #endif
 
-#if defined Q_OS_ANDROID
+#ifdef Q_OS_ANDROID
 int __attribute__((visibility("default"))) main(int argc, char *argv[])
 #else
 int main(int argc, char *argv[])
@@ -58,7 +62,7 @@ int main(int argc, char *argv[])
     format.setOption(QSurfaceFormat::ResetNotification);
     QSurfaceFormat::setDefaultFormat(format);
 
-#if defined Q_OS_ANDROID
+#ifdef Q_OS_ANDROID
     if(argc > 1 && strcmp(argv[1], "-service") == 0){
         QAndroidService app(argc, argv);
         qInfo() << "Service starting...";
@@ -82,13 +86,10 @@ int main(int argc, char *argv[])
 
     KLocalizedString::setApplicationDomain(QByteArrayLiteral("elisa"));
 
-#if QtAndroidExtras_FOUND
+#ifdef Q_OS_ANDROID
     qInfo() << QCoreApplication::arguments();
 
-    QAndroidJniObject::callStaticMethod<void>("org/kde/elisa/ElisaService",
-                                              "startMyService",
-                                              "(Landroid/content/Context;)V",
-                                              QtAndroid::androidContext().object());
+    QJniObject::callStaticMethod<void>("org/kde/elisa/ElisaService", "startMyService", "(Landroid/content/Context;)V", QNativeInterface::QAndroidApplication::context());
 #endif
 
 #if KFCrash_FOUND
@@ -115,6 +116,10 @@ int main(int argc, char *argv[])
 
     KAboutData::setApplicationData(aboutData);
 
+    qmlRegisterSingletonType("org.kde.elisa.about", 1, 0, "About", [](QQmlEngine *engine, QJSEngine *) -> QJSValue {
+        return engine->toScriptValue(KAboutData::applicationData());
+    });
+
     QCommandLineParser parser;
     aboutData.setupCommandLine(&parser);
     parser.process(app);
@@ -140,6 +145,16 @@ int main(int argc, char *argv[])
     // Allow image:// icon URLs to be loaded as images im QML
     engine.addImageProvider(QStringLiteral("icon"), new KQuickIconProvider);
 
+#if KFFileMetaData_FOUND
+    engine.addImageProvider(QStringLiteral("cover"), new EmbeddedCoverageImageProvider);
+#endif
+
+#ifdef Q_OS_ANDROID
+    engine.addImageProvider(QStringLiteral("android"), new AndroidCoverImageProvider);
+#endif
+
+    engine.addImageProvider(QStringLiteral("colorScheme"), new ColorSchemePreviewImageProvider);
+
     engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
 
     QList<QUrl> urls;
@@ -149,7 +164,7 @@ int main(int argc, char *argv[])
 
     engine.rootContext()->setContextProperty(QStringLiteral("elisaStartupArguments"), QVariant::fromValue(urls));
 
-    engine.load(QUrl(QStringLiteral("qrc:/qml/ElisaMainWindow.qml")));
+    engine.loadFromModule("org.kde.elisa", "ElisaMainWindow");
 
     return app.exec();
 }
