@@ -11,16 +11,20 @@
 
 #include <QWriteLocker>
 #include <QReadLocker>
-#include <QtConcurrent>
+#include <QtConcurrentRun>
 
 AbstractMediaProxyModel::AbstractMediaProxyModel(QObject *parent) : QSortFilterProxyModel(parent)
 {
     setFilterCaseSensitivity(Qt::CaseInsensitive);
     mThreadPool.setMaxThreadCount(1);
+
+    connect(&mEnqueueWatcher, &QFutureWatcher<void>::finished, this, &AbstractMediaProxyModel::afterPlaylistEnqueue);
 }
 
 AbstractMediaProxyModel::~AbstractMediaProxyModel()
-= default;
+{
+    disconnect(&mEnqueueWatcher, &QFutureWatcher<void>::finished, this, &AbstractMediaProxyModel::afterPlaylistEnqueue);
+};
 
 QString AbstractMediaProxyModel::filterText() const
 {
@@ -100,6 +104,8 @@ void AbstractMediaProxyModel::disconnectPlayList()
     if (mPlayList) {
         disconnect(this, &AbstractMediaProxyModel::entriesToEnqueue,
                    mPlayList, static_cast<void(MediaPlayListProxyModel::*)(const DataTypes::EntryDataList&, ElisaUtils::PlayListEnqueueMode, ElisaUtils::PlayListEnqueueTriggerPlay)>(&MediaPlayListProxyModel::enqueue));
+        disconnect(this, &AbstractMediaProxyModel::switchToTrackUrl,
+                   mPlayList, static_cast<void(MediaPlayListProxyModel::*)(const QUrl &url, ElisaUtils::PlayListEnqueueTriggerPlay)>(&MediaPlayListProxyModel::switchToTrackUrl));
     }
 }
 
@@ -108,13 +114,16 @@ void AbstractMediaProxyModel::connectPlayList()
     if (mPlayList) {
         connect(this, &AbstractMediaProxyModel::entriesToEnqueue,
                 mPlayList, static_cast<void(MediaPlayListProxyModel::*)(const DataTypes::EntryDataList&, ElisaUtils::PlayListEnqueueMode, ElisaUtils::PlayListEnqueueTriggerPlay)>(&MediaPlayListProxyModel::enqueue));
+        connect(this, &AbstractMediaProxyModel::switchToTrackUrl,
+                mPlayList, static_cast<void(MediaPlayListProxyModel::*)(const QUrl &url, ElisaUtils::PlayListEnqueueTriggerPlay)>(&MediaPlayListProxyModel::switchToTrackUrl));
     }
 }
-void AbstractMediaProxyModel::genericEnqueueToPlayList(const QModelIndex &rootIndex,
+
+QFuture<void> AbstractMediaProxyModel::genericEnqueueToPlayList(const QModelIndex &rootIndex,
                                                        ElisaUtils::PlayListEnqueueMode enqueueMode,
                                                        ElisaUtils::PlayListEnqueueTriggerPlay triggerPlay)
 {
-    QtConcurrent::run(&mThreadPool, [=] () {
+    return QtConcurrent::run(&mThreadPool, [=] () {
         QReadLocker locker(&mDataLock);
         auto allData = DataTypes::EntryDataList{};
         allData.reserve(rowCount());
@@ -138,6 +147,27 @@ void AbstractMediaProxyModel::replaceAndPlayOfPlayList(const QModelIndex &rootIn
     genericEnqueueToPlayList(rootIndex, ElisaUtils::ReplacePlayList, ElisaUtils::TriggerPlay);
 }
 
+void AbstractMediaProxyModel::replaceAndPlayOfPlayListFromTrackUrl(const QModelIndex &rootIndex, const QUrl &switchTrackUrl)
+{
+    auto future = genericEnqueueToPlayList(rootIndex, ElisaUtils::ReplacePlayList, ElisaUtils::DoNotTriggerPlay);
+
+    // Wait until the future is finished before switching tracks
+    mEnqueueWatcher.setFuture(future);
+    mEnqueueWatcherTrackUrl = switchTrackUrl;
+}
+
+void AbstractMediaProxyModel::afterPlaylistEnqueue()
+{
+    if (mEnqueueWatcherTrackUrl.isEmpty()) {
+        return;
+    }
+
+    Q_EMIT switchToTrackUrl(mEnqueueWatcherTrackUrl, ElisaUtils::TriggerPlay);
+
+    // Reset
+    mEnqueueWatcherTrackUrl = QUrl();
+}
+
 void AbstractMediaProxyModel::enqueue(const DataTypes::MusicDataType &newEntry, const QString &newEntryTitle, ElisaUtils::PlayListEnqueueMode enqueueMode, ElisaUtils::PlayListEnqueueTriggerPlay triggerPlay)
 {
     auto allData = DataTypes::EntryDataList{};
