@@ -19,6 +19,7 @@
 #include <KIO/UDSEntry>
 
 #include <QMimeDatabase>
+#include <QQmlEngine>
 #include <QRegularExpression>
 
 #include <queue>
@@ -30,6 +31,8 @@ class ELISALIB_EXPORT FileBrowserProxyModel : public KDirSortFilterProxyModel
 {
     Q_OBJECT
 
+    QML_ELEMENT
+
     Q_PROPERTY(QString filterText
                READ filterText
                WRITE setFilterText
