@@ -12,15 +12,17 @@ public:
     ViewConfigurationDataPrivate()
     = default;
 
+    // Grid/List views
     ViewConfigurationDataPrivate(ElisaUtils::FilterType filterType, int expectedDepth,
                                  QString mainTitle, QString secondaryTitle,
                                  QUrl imageUrl, ElisaUtils::PlayListEntryType dataType,
                                  QAbstractItemModel *model, QAbstractProxyModel *associatedProxyModel,
                                  QUrl viewDefaultIcon, DataTypes::DataType dataFilter,
-                                 int sortRole, QVector<int> sortRoles, QVector<QString> sortRoleNames,
-                                 Qt::SortOrder sortOrder, QVector<QString> sortOrderNames,
+                                 int sortRole, QList<int> sortRoles, QList<QString> sortRoleNames,
+                                 Qt::SortOrder sortOrder, QList<QString> sortOrderNames,
                                  ViewManager::ViewCanBeRated viewShowRating,
-                                 ViewManager::DelegateUseSecondaryText viewDelegateDisplaySecondaryText)
+                                 ViewManager::DelegateUseSecondaryText viewDelegateDisplaySecondaryText,
+                                 ViewManager::ViewStyle viewStyle)
         : mFilterType(filterType)
         , mExpectedDepth(expectedDepth)
         , mMainTitle(std::move(mainTitle))
@@ -38,19 +40,20 @@ public:
         , mSortRoleNames(std::move(sortRoleNames))
         , mSortOrder(sortOrder)
         , mSortOrderNames(std::move(sortOrderNames))
+        , mViewStyle(viewStyle)
     {
     }
 
+    // Track views
     ViewConfigurationDataPrivate(ElisaUtils::FilterType filterType, int expectedDepth,
                                  QString mainTitle, QString secondaryTitle,
                                  QUrl imageUrl, ElisaUtils::PlayListEntryType dataType,
                                  QAbstractItemModel *model, QAbstractProxyModel *associatedProxyModel,
                                  DataTypes::DataType dataFilter,
-                                 int sortRole, QVector<int> sortRoles, QVector<QString> sortRoleNames,
-                                 Qt::SortOrder sortOrder, QVector<QString> sortOrderNames,
+                                 int sortRole, QList<int> sortRoles, QList<QString> sortRoleNames,
+                                 Qt::SortOrder sortOrder, QList<QString> sortOrderNames,
                                  ViewManager::AlbumCardinality displaySingleAlbum,
-                                 ViewManager::AlbumViewStyle showDiscHeaders,
-                                 ViewManager::RadioSpecificStyle radioCase)
+                                 ViewManager::AlbumViewStyle showDiscHeaders)
         : mFilterType(filterType)
         , mExpectedDepth(expectedDepth)
         , mMainTitle(std::move(mainTitle))
@@ -67,7 +70,6 @@ public:
         , mSortOrderNames(std::move(sortOrderNames))
         , mDisplaySingleAlbum(displaySingleAlbum)
         , mShowDiscHeaders(showDiscHeaders)
-        , mRadioCase(radioCase)
     {
     }
 
@@ -97,19 +99,19 @@ public:
 
     int mSortRole;
 
-    QVector<int> mSortRoles;
+    QList<int> mSortRoles;
 
-    QVector<QString> mSortRoleNames;
+    QList<QString> mSortRoleNames;
 
     Qt::SortOrder mSortOrder;
 
-    QVector<QString> mSortOrderNames;
+    QList<QString> mSortOrderNames;
 
     ViewManager::AlbumCardinality mDisplaySingleAlbum;
 
     ViewManager::AlbumViewStyle mShowDiscHeaders;
 
-    ViewManager::RadioSpecificStyle mRadioCase;
+    ViewManager::ViewStyle mViewStyle = ViewManager::ListStyle;
 };
 
 ViewConfigurationData::ViewConfigurationData(QObject *parent)
@@ -118,15 +120,17 @@ ViewConfigurationData::ViewConfigurationData(QObject *parent)
 {
 }
 
+// Grid/List views
 ViewConfigurationData::ViewConfigurationData(ElisaUtils::FilterType filterType, int expectedDepth,
                                              QString mainTitle, QString secondaryTitle,
                                              QUrl imageUrl, ElisaUtils::PlayListEntryType dataType,
                                              QAbstractItemModel *model, QAbstractProxyModel *associatedProxyModel,
                                              QUrl viewDefaultIcon, DataTypes::DataType dataFilter,
-                                             int sortRole, QVector<int> sortRoles, QVector<QString> sortRoleNames,
-                                             Qt::SortOrder sortOrder, QVector<QString> sortOrderNames,
+                                             int sortRole, QList<int> sortRoles, QList<QString> sortRoleNames,
+                                             Qt::SortOrder sortOrder, QList<QString> sortOrderNames,
                                              ViewManager::ViewCanBeRated viewShowRating,
                                              ViewManager::DelegateUseSecondaryText viewDelegateDisplaySecondaryText,
+                                             ViewManager::ViewStyle viewStyle,
                                              QObject *parent)
     : QObject(parent)
     , d(std::make_unique<ViewConfigurationDataPrivate>(filterType, expectedDepth, std::move(mainTitle),
@@ -135,28 +139,28 @@ ViewConfigurationData::ViewConfigurationData(ElisaUtils::FilterType filterType,
                                                        std::move(viewDefaultIcon), std::move(dataFilter),
                                                        sortRole, std::move(sortRoles), std::move(sortRoleNames),
                                                        sortOrder, std::move(sortOrderNames),
-                                                       viewShowRating,viewDelegateDisplaySecondaryText))
+                                                       viewShowRating, viewDelegateDisplaySecondaryText,
+                                                       viewStyle))
 {
 }
 
+// Track views
 ViewConfigurationData::ViewConfigurationData(ElisaUtils::FilterType filterType, int expectedDepth,
                                              QString mainTitle, QString secondaryTitle,
                                              QUrl imageUrl, ElisaUtils::PlayListEntryType dataType,
                                              QAbstractItemModel *model, QAbstractProxyModel *associatedProxyModel,
                                              DataTypes::DataType dataFilter,
-                                             int sortRole, QVector<int> sortRoles, QVector<QString> sortRoleNames,
-                                             Qt::SortOrder sortOrder, QVector<QString> sortOrderNames,
+                                             int sortRole, QList<int> sortRoles, QList<QString> sortRoleNames,
+                                             Qt::SortOrder sortOrder, QList<QString> sortOrderNames,
                                              ViewManager::AlbumCardinality displaySingleAlbum,
                                              ViewManager::AlbumViewStyle showDiscHeaders,
-                                             ViewManager::RadioSpecificStyle radioCase,
                                              QObject *parent)
     : QObject(parent)
     , d(std::make_unique<ViewConfigurationDataPrivate>(filterType, expectedDepth, std::move(mainTitle),
                                                        std::move(secondaryTitle), std::move(imageUrl),
                                                        dataType, model, associatedProxyModel, std::move(dataFilter),
                                                        sortRole, std::move(sortRoles), std::move(sortRoleNames),
-                                                       sortOrder, std::move(sortOrderNames), displaySingleAlbum, showDiscHeaders,
-                                                       radioCase))
+                                                       sortOrder, std::move(sortOrderNames), displaySingleAlbum, showDiscHeaders))
 {
 }
 
@@ -225,12 +229,12 @@ int ViewConfigurationData::sortRole() const
     return d->mSortRole;
 }
 
-QVector<int> ViewConfigurationData::sortRoles() const
+QList<int> ViewConfigurationData::sortRoles() const
 {
     return d->mSortRoles;
 }
 
-QVector<QString> ViewConfigurationData::sortRoleNames() const
+QList<QString> ViewConfigurationData::sortRoleNames() const
 {
     return d->mSortRoleNames;
 }
@@ -240,7 +244,7 @@ Qt::SortOrder ViewConfigurationData::sortOrder() const
     return d->mSortOrder;
 }
 
-QVector<QString> ViewConfigurationData::sortOrderNames() const
+QList<QString> ViewConfigurationData::sortOrderNames() const
 {
     return d->mSortOrderNames;
 }
@@ -255,9 +259,9 @@ ViewManager::AlbumViewStyle ViewConfigurationData::showDiscHeaders() const
     return d->mShowDiscHeaders;
 }
 
-ViewManager::RadioSpecificStyle ViewConfigurationData::radioCase() const
+ViewManager::ViewStyle ViewConfigurationData::viewStyle() const
 {
-    return d->mRadioCase;
+    return d->mViewStyle;
 }
 
 ViewConfigurationData::~ViewConfigurationData() = default;
